/*
 * file StpPropertyException.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.StpPropertyException
 *
 * (C) Copyright IBM Corporation 2006, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp;

import javax.wvcm.Resource;
import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;


/**
 * The base exception class for errors associated with the reading or writing of
 * resource properties and meta-properties.
 */
public abstract class StpPropertyException extends StpException
{

    /**
     * Returns the name of the property with which this exception is associated.
     *
     * @return The property name. Will never be null.
     */
    public PropertyName<?> getPropertyName()
    { return ((PropertyData)data()).getPropertyName(); }
    
    /**
     * Constructs this exception object for its subclasses.
     * 
     * @param resource The Resource argument to WvcmException
     * @param reasonCode The ReasonCode argument to WvcmException
     * @param nestedExceptions The Throwable[] argument to WvcmException
     * 
     * @see javax.wvcm.WvcmException
     */
    protected StpPropertyException(Resource resource,
                                ReasonCode reasonCode,
                                Throwable... nestedExceptions)
    {
        super(resource, reasonCode, nestedExceptions);
    }

    /** 
     * The interface specification for the implementation data object 
     * associated with this exception
     */
    public interface PropertyData extends Data
    {
        public PropertyName<?> getPropertyName();
    }
}
